OC.L10N.register(
    "lib",
    {
    "See %s" : "%s kucken",
    "Sample configuration detected" : "Beispill-Konfiguratioun erkannt",
    "PHP %s or higher is required." : "PHP %s oder méi nei ass néideg.",
    "PHP with a version lower than %s is required." : "PHP mat enger Versioun %s oder méi kleng ass néideg.",
    "Following databases are supported: %s" : "Dës Datebanke ginn ënnerstëtzt: %s",
    "Unknown filetype" : "Onbekannten Fichier Typ",
    "Invalid image" : "Ongülteg d'Bild",
    "today" : "haut",
    "yesterday" : "gëschter",
    "_%n day ago_::_%n days ago_" : ["%n Dag hier","%n Deeg hier"],
    "last month" : "Läschte Mount",
    "_%n month ago_::_%n months ago_" : ["%n Mount hier","%n Méint hier"],
    "last year" : "Läscht Joer",
    "_%n year ago_::_%n years ago_" : ["%n Joer hier","%n Joer hier"],
    "_%n hour ago_::_%n hours ago_" : ["%n Stonn hier","%n Stonnen hier"],
    "seconds ago" : "Sekonnen hir",
    "None" : "Keng",
    "Username" : "Benotzernumm",
    "Password" : "Passwuert",
    "File name contains at least one invalid character" : "Den Numm vum Fichier entält min. een ongültegz Zeechen",
    "Apps" : "Applikatiounen",
    "General" : "Allgemeng",
    "Security" : "Sécherheet",
    "Encryption" : "Verschlësselung",
    "Sharing" : "Gedeelt",
    "Search" : "Sichen",
    "Updates" : "Updates",
    "%s shared »%s« with you" : "Den/D' %s huet »%s« mat dir gedeelt",
    "A valid username must be provided" : "Et muss e gültegen Benotzernumm ugi ginn",
    "A valid password must be provided" : "Et muss e gültegt Passwuert ugi ginn",
    "Help" : "Hëllef",
    "Settings" : "Astellungen",
    "Users" : "Benotzer",
    "web services under your control" : "Web-Servicer ënnert denger Kontroll",
    "Authentication error" : "Authentifikatioun's Fehler",
    "Imprint" : "Impressum",
    "__language_name__" : "__language_name__"
},
"nplurals=2; plural=(n != 1);");
